{% if messages %}
    <ul class="flex flex-col gap-4 mb-8">
        {% for message in messages %}
            <li class="*:!mb-0">
                {% if message.tags == 'info' %}
                    {% include "unfold/helpers/messages/info.html" with message=message %}
                {% elif message.tags == 'success' %}
                    {% include "unfold/helpers/messages/success.html" with message=message %}
                {% elif message.tags == 'warning' %}
                    {% include "unfold/helpers/messages/warning.html" with message=message %}
                {% elif message.tags == 'error' %}
                    {% include "unfold/helpers/messages/error.html" with message=message %}
                {% else %}
                    {% include "unfold/helpers/messages/debug.html" with message=message %}
                {% endif %}
            </li>
        {% endfor %}
    </ul>
{% endif %}
