{% extends "admin/base.html" %}

{% load i18n %}

{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="px-12">
            <div class="container mb-12 mx-auto -my-3">
                <ul class="flex flex-wrap">
                    {% url 'admin:index' as link %}
                    {% trans 'Home' as name %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=name %}

                    {% for app in app_list %}
                        {% include 'unfold/helpers/breadcrumb_item.html' with link='' name=app.name|capfirst %}
                    {% endfor %}
                </ul>
            </div>
        </div>
    {% endblock %}
{% endif %}

{% block branding %}
    {% include "unfold/helpers/site_branding.html" %}
{% endblock %}

{% block content %}
    <div class="flex flex-row -mx-4">
        <div class="flex-grow px-4">
            {% include "unfold/helpers/app_list_default.html" %}
        </div>
    </div>
{% endblock %}

{% block sidebar %}{% endblock %}
