{% load unfold %}

<div class="{% fieldset_row_classes %} {% if forloop.last %}last{% endif %}">
    {% for field in line %}
        <div class="{% fieldset_line_classes %}">
            {% if field.is_checkbox %}
                {% include "unfold/helpers/fieldset_row_checkbox.html" %}
            {% else %}
                {% include "unfold/helpers/fieldset_row_field.html" %}
            {% endif %}
        </div>
    {% endfor %}
</div>
