{% load i18n %}

<div class="flex flex-col gap-3 items-center w-full lg:flex-row">
    <a href="#" class="border cancel-link flex items-center justify-center font-medium px-3 py-2 rounded w-full hover:bg-base-50 lg:block lg:mb-0 lg:w-auto dark:border-base-700 dark:text-font-default-dark dark:hover:text-base-200 dark:hover:bg-base-900">
        {% translate "No, take me back" %}
    </a>

    <button type="submit" class="bg-red-600 cursor-pointer flex items-center justify-center font-medium h-9.5 ml-0 px-3 py-2 rounded text-white w-full lg:ml-auto lg:w-auto dark:bg-red-500/20 dark:text-red-500">
        {% translate "Yes, I’m sure" %}
    </button>
</div>
