{% if not is_popup %}
    {% block header %}
        <div class="border-b border-base-200 mb-6 px-4 lg:px-8 dark:border-base-800">
            <div class="{% if not cl.model_admin.list_fullwidth %}container{% endif %} flex items-center h-16 mx-auto py-4">
                <div id="header-inner" class="flex items-center w-full">
                    <div class="flex items-center w-full">
                        {% block usertools %}
                            {% if has_permission %}
                                {% block welcome-msg %}
                                    {% include 'unfold/helpers/welcomemsg.html' %}
                                {% endblock %}

                                {% block userlinks %}
                                    {% include 'unfold/helpers/userlinks.html' %}
                                {% endblock %}
                            {% endif %}
                        {% endblock %}
                    </div>
                </div>
            </div>
        </div>
    {% endblock %}
{% endif %}
