{% if results %}
    <ul class="absolute bg-white border border-base-200 left-0 mt-12 right-0 rounded top-0 shadow-sm text-sm z-10 dark:bg-base-800 dark:border-base-700">
        {% for app in results %}
            {% for model in app.models %}
                <li>
                    <a href="{{ model.admin_url }}" class="block px-3 py-2 truncate hover:text-base-700 dark:hover:text-base-200">
                        {{ app.name }} <span class="align-text-top material-symbols-outlined md-18">arrow_right_alt</span> {{ model.name }}
                    </a>
                </li>
            {% endfor %}
        {% endfor %}
    </ul>
{% endif %}
