{% if widget.wrap_label %}
    <label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %} class="flex flex-row items-center gap-2">
{% endif %}

{% include "django/forms/widgets/input.html" %}

{% if widget.wrap_label %}
    <span>
        {{ widget.label }}
    </span>
    </label>
{% endif %}
