{% extends "admin/base_site.html" %}
{% load admin_modify admin_urls i18n static  %}

{% block extrastyle %}
    {{ block.super }}

    <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />
{% endblock %}

{% block bodyclass %}
    {{ block.super }} {{ opts.app_label }}-{{ opts.object_name.lower }} change-form
{% endblock %}
