{% load i18n %}

<div class="relative min-w-sidebar transition-width w-sidebar z-30">
    <nav id="nav-sidebar" class="bg-base-50 border-r border-base-200 bottom-0 fixed max-h-screen top-0 transition-width w-sidebar dark:bg-base-900 dark:border-base-800">
        <div class="flex flex-col min-h-screen min-w-sidebar dark:bg-base-950/20">
            {% include "unfold/helpers/navigation_header.html" %}

            {% include "unfold/helpers/search.html" %}

            {% if sidebar_navigation|length > 0 %}
                {% include "unfold/helpers/app_list.html" with app_list=available_apps %}
            {% else %}
                {% include "admin/app_list.html" with app_list=available_apps show_changelinks=False %}
            {% endif %}
        </div>
    </nav>
</div>
